partis.schema.prim package
==========================

.. toctree::
   :maxdepth: 2

   partis.schema.prim.base
   partis.schema.prim.bool_prim
   partis.schema.prim.float_prim
   partis.schema.prim.int_prim
   partis.schema.prim.map_prim
   partis.schema.prim.pass_prim
   partis.schema.prim.seq_prim
   partis.schema.prim.str_prim
   partis.schema.prim.union_prim
